@@ -441,10 +441,6 @@ class IBehaviorProperties(typing_extensions.Protocol):
     :see: https://aws.github.io/jsii/user-guides/lib-author/typescript-restrictions/#interfaces
     '''
 
-    @builtins.staticmethod
-    def __jsii_proxy_class__() -> typing.Type["_IBehaviorPropertiesProxy"]:
-        return _IBehaviorPropertiesProxy
-
     @builtins.property # type: ignore[misc]
     @jsii.member(jsii_name="otherProp")
     def other_prop(self) -> builtins.str:
@@ -467,6 +463,9 @@ class _IBehaviorPropertiesProxy:
     def other_prop(self) -> builtins.str:
         return typing.cast(builtins.str, jsii.get(self, "otherProp"))
 
+# Adding a "__jsii_proxy_class__(): typing.Type" function to the interface
+typing.cast(typing.Any, IBehaviorProperties).__jsii_proxy_class__ = lambda : _IBehaviorPropertiesProxy
+
 
 class LambdaConstruct(
     aws_cdk.core.Construct,
